@@ -14,7 +14,7 @@
 #' for the module.
 #' The `functionCoverage` object contains percentage values for unit test
 #' coverage for each function defined in the module.
-#' Please use [covr::report()] to view the coverage information.
+#' Please use `covr::report()` to view the coverage information.
 #' Two data.tables give the information of all the tested and untested functions
 #' in the module.
 #'
@@ -28,25 +28,13 @@
 #' @seealso [newModule()].
 #'
 #' @author Yong Luo
-#' @export
 #' @importFrom data.table data.table
-#' @importFrom reproducible file.move
+#' @importFrom reproducible .file.move
 #' @include simList-class.R
 #' @rdname moduleCoverage
 #'
-#' @examples
-#' \dontrun{
-#'   tmpdir <- file.path(tempdir(), "coverage")
-#'   modulePath <- file.path(tmpdir, "Modules") %>% checkPath(create = TRUE)
-#'   moduleName <- "forestAge" # sample module to test
-#'   downloadModule(name = moduleName, path = modulePath) # download sample module
-#'   testResults <- moduleCoverage(name = moduleName, path = modulePath)
-#'   report(testResults$moduleCoverage)
-#'   report(testResults$functionCoverage)
-#'   unlink(tmpdir, recursive = TRUE)
-#'   mc1 <- moduleCoverage("Biomass_core", modulePath = "..")
-#' }
 moduleCoverage <- function(mod, modulePath = "..") {
+  stop("This is a stub that is not intended for use")
   if (requireNamespace("testthat")) {
     if (is.null(getOption("testthat.progress.max_fails"))) {
       options(testthat.progress.max_fails = Inf)
@@ -69,8 +57,8 @@ moduleCoverage <- function(mod, modulePath = "..") {
     b <- parse(file = modFileNam)
     defModLine <- grep("defineModule", b)
     tf <- tempfile(fileext = ".R")
-    file.move(modFileNam, tf)
-    on.exit(file.move(tf, modFileNam, overwrite = TRUE), add = TRUE)
+    .file.move(modFileNam, tf)
+    on.exit(.file.move(tf, modFileNam, overwrite = TRUE), add = TRUE)
     cat(do.call(c, lapply(b[-defModLine], function(x) format(x))),
         file = tmpFile, sep = "\n")
     cat(do.call(c, lapply(b[defModLine], function(x) format(x))),
@@ -85,10 +73,9 @@ moduleCoverage <- function(mod, modulePath = "..") {
     ################
     options(opts)
     test_files <- dir(file.path("tests", "testthat"), full.names = TRUE)
-    bb <- covr::file_coverage(source_files = checkPath(dir("R", full.names = TRUE)),
+    bb <- covr::file_coverage(source_files = checkPath(dir("R", full.names = TRUE, pattern = "\\.R")),
                               test_files = grep("Ward", test_files, value = TRUE) )
     #################
-    browser()
 
 
     ignore <- lapply(test_files, source)
@@ -99,7 +86,6 @@ moduleCoverage <- function(mod, modulePath = "..") {
     options(opts)
 
     # Now do tests all 2nd time, but this time testing unique function calls without `spades` or `simInit`
-    browser()
     # test_files <- dir(file.path(modulePath, mod, "tests"), pattern = ".R$", full.names = TRUE)
     bb <- covr::file_coverage(source_files = checkPath(dir("R", full.names = TRUE)),
                         test_files = test_files )
