@@ -1,25 +1,25 @@
-#' @importFrom reproducible paddedFloatToChar
-#' @export
-reproducible::paddedFloatToChar
+## non-exported imports from other packages -------------------------------------
 
-filePathSansExt <- getFromNamespace("filePathSansExt", ns = "reproducible")
-messageColoured <- utils::getFromNamespace("messageColoured", "reproducible")
-messageVerbose <- utils::getFromNamespace("messageVerbose", "Require")
+.message <- getFromNamespace(".message", "reproducible") ## envir for messages + message-funs
+.quickPlotEnv <- getFromNamespace(".quickPlotEnv", "quickPlot")
+
+## TODO: why aren't these properly exported if intended for use?
+## see <https://github.com/PredictiveEcology/Require/issues/105>
+## and <https://github.com/PredictiveEcology/reproducible/issues/389>
+compareVersion2 <- getFromNamespace("compareVersion2", "Require")
+extractInequality <- getFromNamespace("extractInequality", "Require")
 
 getDrv <- getFromNamespace("getDrv", "reproducible")
 isWindows <- getFromNamespace("isWindows", "reproducible")
-makeAbsolute <- getFromNamespace("makeAbsolute", "reproducible")
 isAbsolutePath <- getFromNamespace("isAbsolutePath", "reproducible")
 isRaster <- getFromNamespace("isRaster", "reproducible")
 isSpat <- getFromNamespace("isSpat", "reproducible")
 layerNamesDelimiter <- getFromNamespace("layerNamesDelimiter", "reproducible")
 
-.quickPlotEnv <- getFromNamespace(".quickPlotEnv", "quickPlot")
+makeAbsolute <- getFromNamespace("makeAbsolute", "reproducible")
 
-fileExt <- getFromNamespace("fileExt", "reproducible")
-filePathSansExt <- getFromNamespace("filePathSansExt", "reproducible")
-extractInequality <- getFromNamespace("extractInequality", "Require")
-compareVersion2 <- getFromNamespace("compareVersion2", "Require")
+## re-exported functions --------------------------------------------------------
 
-.addingToMemoisedMsg <- getFromNamespace(".addingToMemoisedMsg", "reproducible")
-remapFilenames <- getFromNamespace("remapFilenames", "reproducible")
+#' @importFrom reproducible paddedFloatToChar
+#' @export
+reproducible::paddedFloatToChar
