@@ -20,11 +20,10 @@ cleanMessage <- function(mm) {
 #   optsAsk in this environment,
 testInit <- function(libraries = character(), ask = FALSE, verbose,
                      debug = FALSE, tmpFileExt = "",
-                     opts = NULL, needGoogleDriveAuth = FALSE, smcc = FALSE) {
+                     opts = NULL, needGoogleDriveAuth = FALSE, smcc = FALSE,
+                     pf = parent.frame()) {
   set.randomseed()
 
-  pf <- parent.frame()
-
   if (isTRUE(needGoogleDriveAuth))
     libraries <- c(libraries, "googledrive")
   if (length(libraries)) {
@@ -252,3 +251,7 @@ runTestsWithTimings <- function(pkgPath = ".",
   data.table::setorderv(gg, c("skipOnCRAN", "elapsed"), order = c(1L, -1L))
   gg[]
 }
+
+LoadedMgsCheck <- function(msg, event) {
+  sum(grepl(paste0("Loaded! Cached|for ", event," event"), msg)) == 2
+}
