@@ -35,13 +35,13 @@ test_that("simList object initializes correctly (1)", {
   options(width = 100L)
   out <- utils::capture.output(show(mySim))
 
-  expect_equal(length(out), 81)
+  expect_equal(length(out), 82)
   options(width = w)
   rm(w)
 
   ## test path accessors
-  expect_identical(figurePath(mySim), normPath(file.path(outputPath(mySim), "figures")))
-  expect_identical(logPath(mySim), normPath(file.path(outputPath(mySim), "log")))
+  expect_identical(normPath(figurePath(mySim)), normPath(file.path(outputPath(mySim), "figures")))
+  expect_identical(normPath(logPath(mySim)), normPath(file.path(outputPath(mySim), "log")))
 
   ### SLOT .xData
   expect_is(envir(mySim), "environment")
